@@ -1,7 +1,7 @@
 package Net::Stripe::BalanceTransaction;
-$Net::Stripe::BalanceTransaction::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::BalanceTransaction::VERSION = '0.40005';use Moose;
+$Net::Stripe::BalanceTransaction::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::BalanceTransaction::VERSION = '0.42001';
+use Moose;
 use Moose::Util::TypeConstraints qw(subtype as where message);
 extends 'Net::Stripe::Resource';
 
@@ -43,7 +43,7 @@ Net::Stripe::BalanceTransaction - represent a BalanceTransaction object from Str
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
