@@ -1,7 +1,7 @@
 package Net::Stripe::Card;
-$Net::Stripe::Card::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Card::VERSION = '0.40005';use Moose;
+$Net::Stripe::Card::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Card::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 use Net::Stripe::Token;
 
@@ -66,7 +66,7 @@ Net::Stripe::Card - represent a Card object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
