@@ -1,7 +1,7 @@
 package Net::Stripe::Charge;
-$Net::Stripe::Charge::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Charge::VERSION = '0.40005';use Moose;
+$Net::Stripe::Charge::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Charge::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -52,7 +52,7 @@ Net::Stripe::Charge - represent an Charge object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
