@@ -1,7 +1,7 @@
 package Net::Stripe::Coupon;
-$Net::Stripe::Coupon::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Coupon::VERSION = '0.40005';use Moose;
+$Net::Stripe::Coupon::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Coupon::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -35,7 +35,7 @@ Net::Stripe::Coupon - represent a Coupon object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
