@@ -1,7 +1,7 @@
 package Net::Stripe::Customer;
-$Net::Stripe::Customer::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Customer::VERSION = '0.40005';use Moose;
+$Net::Stripe::Customer::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Customer::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 use Net::Stripe::Plan;
 use Net::Stripe::Token;
@@ -88,7 +88,7 @@ Net::Stripe::Customer - represent a Customer object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
