@@ -1,7 +1,7 @@
 package Net::Stripe::Discount;
-$Net::Stripe::Discount::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Discount::VERSION = '0.40005';use Moose;
+$Net::Stripe::Discount::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Discount::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -23,7 +23,7 @@ Net::Stripe::Discount - represent a Discount object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
