@@ -1,7 +1,7 @@
 package Net::Stripe::Error;
-$Net::Stripe::Error::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Error::VERSION = '0.40005';use Moose;
+$Net::Stripe::Error::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Error::VERSION = '0.42001';
+use Moose;
 with 'Throwable';
 use namespace::clean -except => 'meta';
 
@@ -34,7 +34,7 @@ Net::Stripe::Error - represent an error result from interacting with Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
