@@ -1,7 +1,7 @@
 package Net::Stripe::Invoice;
-$Net::Stripe::Invoice::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Invoice::VERSION = '0.40005';use Moose;
+$Net::Stripe::Invoice::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Invoice::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -62,7 +62,7 @@ Net::Stripe::Invoice - represent an Invoice object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
