@@ -1,7 +1,7 @@
 package Net::Stripe::Invoiceitem;
-$Net::Stripe::Invoiceitem::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Invoiceitem::VERSION = '0.40005';use Moose;
+$Net::Stripe::Invoiceitem::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Invoiceitem::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 with 'MooseX::Clone';
@@ -37,7 +37,7 @@ Net::Stripe::Invoiceitem - represent an Invoice Item object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
