@@ -1,7 +1,7 @@
 package Net::Stripe::LineItem;
-$Net::Stripe::LineItem::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::LineItem::VERSION = '0.40005';use Moose;
+$Net::Stripe::LineItem::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::LineItem::VERSION = '0.42001';
+use Moose;
 
 # ABSTRACT: represent an Line Item object from Stripe
 
@@ -30,7 +30,7 @@ Net::Stripe::LineItem - represent an Line Item object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
