@@ -1,7 +1,7 @@
 package Net::Stripe::List;
-$Net::Stripe::List::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::List::VERSION = '0.40005';use Moose;
+$Net::Stripe::List::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::List::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 
 # ABSTRACT: represent a list of objects from Stripe
@@ -67,7 +67,7 @@ Net::Stripe::List - represent a list of objects from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
