@@ -1,7 +1,7 @@
 package Net::Stripe::PaymentMethod;
-$Net::Stripe::PaymentMethod::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::PaymentMethod::VERSION = '0.40005';use Moose;
+$Net::Stripe::PaymentMethod::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::PaymentMethod::VERSION = '0.42001';
+use Moose;
 use Moose::Util::TypeConstraints qw(enum);
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -43,7 +43,7 @@ Net::Stripe::PaymentMethod - represent a PaymentMethod object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
