@@ -1,7 +1,7 @@
 package Net::Stripe::Plan;
-$Net::Stripe::Plan::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Plan::VERSION = '0.40005';use Moose;
+$Net::Stripe::Plan::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Plan::VERSION = '0.42001';
+use Moose;
 use Moose::Util::TypeConstraints qw(subtype as where message);
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -44,7 +44,7 @@ Net::Stripe::Plan - represent a Plan object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
