@@ -1,7 +1,7 @@
 package Net::Stripe::Refund;
-$Net::Stripe::Refund::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Refund::VERSION = '0.40005';use Moose;
+$Net::Stripe::Refund::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Refund::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -50,7 +50,7 @@ Net::Stripe::Refund - represent a Refund object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
