@@ -1,7 +1,7 @@
 package Net::Stripe::Source;
-$Net::Stripe::Source::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Source::VERSION = '0.40005';use Moose;
+$Net::Stripe::Source::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Source::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -49,7 +49,7 @@ Net::Stripe::Source - represent a Source object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
