@@ -1,7 +1,7 @@
 package Net::Stripe::Subscription;
-$Net::Stripe::Subscription::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Subscription::VERSION = '0.40005';use Moose;
+$Net::Stripe::Subscription::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Subscription::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 use Net::Stripe::Token;
 use Net::Stripe::Card;
@@ -52,7 +52,7 @@ Net::Stripe::Subscription - represent a Subscription object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
