@@ -1,7 +1,7 @@
 package Net::Stripe::Token;
-$Net::Stripe::Token::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::Token::VERSION = '0.40005';use Moose;
+$Net::Stripe::Token::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::Token::VERSION = '0.42001';
+use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
 
@@ -39,7 +39,7 @@ Net::Stripe::Token - represent a Token object from Stripe
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 ATTRIBUTES
 
