@@ -1,7 +1,7 @@
 package Net::Stripe::TypeConstraints;
-$Net::Stripe::TypeConstraints::VERSION = '0.40_005'; # TRIAL
-
-$Net::Stripe::TypeConstraints::VERSION = '0.40005';use strict;
+$Net::Stripe::TypeConstraints::VERSION = '0.42_001'; # TRIAL
+$Net::Stripe::TypeConstraints::VERSION = '0.42001';
+use strict;
 use Moose::Util::TypeConstraints qw/subtype as where message enum/;
 
 # ABSTRACT: Custom Moose TypeConstraints for Net::Stripe object attributes and parameters
@@ -131,7 +131,7 @@ Net::Stripe::TypeConstraints - Custom Moose TypeConstraints for Net::Stripe obje
 
 =head1 VERSION
 
-version 0.40_005
+version 0.42_001
 
 =head1 AUTHORS
 
